@@ -43,6 +43,7 @@ pub trait StorageBackend:
     + Fetch<(), LedgerIndex>
     + Fetch<Address, Balance>
     + Fetch<bool, Vec<TreasuryOutput>>
+    + Fetch<Ed25519Address, Vec<OutputId>>
     + Insert<(), SnapshotInfo>
     + Insert<(), LedgerIndex>
     + Insert<(bool, TreasuryOutput), ()>
@@ -72,6 +73,7 @@ impl<T> StorageBackend for T where
         + Fetch<(), LedgerIndex>
         + Fetch<Address, Balance>
         + Fetch<bool, Vec<TreasuryOutput>>
+        + Fetch<Ed25519Address, Vec<OutputId>>
         + Insert<(), SnapshotInfo>
         + Insert<(), LedgerIndex>
         + Insert<(bool, TreasuryOutput), ()>
@@ -405,6 +407,15 @@ pub(crate) async fn fetch_output<B: StorageBackend>(
         .map_err(|e| Error::Storage(Box::new(e)))
 }
 
+pub(crate) async fn fetch_outputs_for_ed25519_address<B: StorageBackend>(
+    storage: &B,
+    address: &Ed25519Address,
+) -> Result<Option<Vec<OutputId>>, Error> {
+    Fetch::<Ed25519Address, Vec<OutputId>>::fetch(&*storage, &address)
+        .await
+        .map_err(|e| Error::Storage(Box::new(e)))
+}
+
 pub(crate) async fn is_output_unspent<B: StorageBackend>(storage: &B, output_id: &OutputId) -> Result<bool, Error> {
     Exist::<Unspent, ()>::exist(storage, &(*output_id).into())
         .await
